.. _libdoc_rng_mrg:

===================================================================
:mod:`sandbox.rng_mrg` --  MRG random number generator
===================================================================

.. module:: sandbox.rng_mrg
   :platform: Unix, Windows
   :synopsis: MRG random number generator
.. moduleauthor:: LISA

API
===

.. automodule:: aesara.sandbox.rng_mrg
    :members:
